from marketorestpython.client import MarketoClient
from itertools import chain
import os


class Marketo(MarketoClient):
    def __init__(self, munchkin_id, client_id, client_secret):
        super().__init__(client_server, client_id, client_secret)

    def get_all_segments(self):
        results = list()
        segmentations = self.get_segmentations()
        all_segments = list(chain.from_iterable(
            map((lambda s: self.get_segments(s['id'])), segmentations)))
        return all_segments

    def get_all_programs(self):
        results = list()
        programs = self.browse_programs()
        all_programs = list(chain.from_iterable(
            map((lambda p: self.get_program_by_id(p['id'])), programs)))
        return all_programs

# def main():
#     mkto = Marketo(os.getenv('MKTO_CLIENT_SERVER'), os.getenv('MKTO_CLIENT_ID'), os.getenv('MKTO_CLIENT_SECRET'))
#     # print(len(mkto.get_multiple_campaigns()))
#     # print(len(mkto.get_all_segments()))
#     # print(mkto.get_all_programs())
#     # print(len(mkto.get_activity_types()))


# if __name__ == '__main__':
#     main()



from setuptools import setup, find_packages

import os
import sys


# Don't import analytics-python module here, since deps may not be installed
# sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'pymarketo'))

# python setup.py register -r pypi
# python setup.py sdist upload -r pypi

long_description = '''
PyMarketo is a Python client that wraps the MarketoRestPython project to provide a human friendly module and add bulk export capability.
'''

setup(
    name='pymarketo',
    version='1.1.1',
    description='Python Client for the Marketo REST API',
    url='https://github.com/osamakhn/pymarketo',
    author='Osama Khan',
    author_email='osamakhn@gmail.com',
    license='MIT License',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    install_requires=[
        'requests',
        'marketorestpython'
    ],
    long_description=long_description,
    keywords='Marketo REST API Wrapper Client',
    classifier=['Intended Audience :: Developers',
                'Programming Language :: Python :: 3'],
    project_urls={
        'Source': 'https://www.github.com/osamakhn/pymarketo'
    }
)
